
.. toctree::
   :hidden:

   README.md

.. toctree::
   :hidden:

   tutorials/tutorials
   api/api
   references/references
   misc/misc



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

..
